@@ -4,7 +4,7 @@ require 'json/editor'
 
 filename, encoding = ARGV
 JSON::Editor.start(encoding) do |window|
-  if filename and File.exist?(filename)
+  if filename
     window.file_open(filename)
   end
 end
